@@ -1,7 +1,7 @@
-from .segmentation import relabel_, unary_masks2labels
+from .segmentation import relabel_, unary_masks2labels, boxes2masks
 from .cpn import CPNTargetGenerator, contours2labels, render_contour, clip_contour_, masks2labels, \
     labels2contour_list as labels2contours
 from .misc import to_tensor, transpose_spatial, universal_dict_collate_fn, normalize_percentile, random_crop, \
-    channels_last2channels_first, channels_first2channels_last
+    channels_last2channels_first, channels_first2channels_last, ensure_tensor, rgb_to_scalar
 from .instance_eval import LabelMatcherList, LabelMatcher
 from .datasets import *
